@@ -1,18 +1,21 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
 
-from datetime import datetime, timedelta
 import importlib
 import logging
+from datetime import datetime, timedelta
+from typing import Any
 
-from confluent_kafka import Consumer, KafkaException, KafkaError
+from confluent_kafka import (
+    Consumer, KafkaError, KafkaException,
+)
+from pyhocon import ConfigTree
 
 from databuilder import Scoped
 from databuilder.callback.call_back import Callback
 from databuilder.extractor.base_extractor import Extractor
 from databuilder.transformer.base_transformer import Transformer
 
-
 LOGGER = logging.getLogger(__name__)
 
 
@@ -47,13 +50,12 @@ class KafkaSourceExtractor(Extractor, Callback):
     # The value transformer to deserde the Kafka message
     RAW_VALUE_TRANSFORMER = 'raw_value_transformer'
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         self.conf = conf
         self.consumer_config = conf.get_config(KafkaSourceExtractor.CONSUMER_CONFIG).\
             as_plain_ordered_dict()
 
-        self.topic_names = conf.get_list(KafkaSourceExtractor.TOPIC_NAME_LIST)  # type: list
+        self.topic_names: list = conf.get_list(KafkaSourceExtractor.TOPIC_NAME_LIST)
 
         if not self.topic_names:
             raise Exception('Kafka topic needs to be provided by the user.')
@@ -94,8 +96,7 @@ class KafkaSourceExtractor(Extractor, Callback):
         except Exception:
             raise RuntimeError('Consumer could not start correctly!')
 
-    def extract(self):
-        # type: () -> Any
+    def extract(self) -> Any:
         """
         :return: Provides a record or None if no more to extract
         """
@@ -112,13 +113,12 @@ class KafkaSourceExtractor(Extractor, Callback):
                     # Users need to figure out how to rewind the consumer offset
                     raise Exception('Encounter exception when transform the record')
 
-    def on_success(self):
-        # Type: () -> None
+    def on_success(self) -> None:
         """
         Commit the offset
         once:
             1. get the success callback from publisher in
-            https://github.com/lyft/amundsendatabuilder/blob/
+            https://github.com/amundsen-io/amundsendatabuilder/blob/
             master/databuilder/publisher/base_publisher.py#L50
             2. close the consumer.
 
@@ -129,13 +129,11 @@ class KafkaSourceExtractor(Extractor, Callback):
             self.consumer.commit(asynchronous=False)
             self.consumer.close()
 
-    def on_failure(self):
-        # Type: () -> None
+    def on_failure(self) -> None:
         if self.consumer:
             self.consumer.close()
 
-    def consume(self):
-        # Type: () -> Any
+    def consume(self) -> Any:
         """
         Consume messages from a give list of topic
 
@@ -170,6 +168,5 @@ class KafkaSourceExtractor(Extractor, Callback):
         finally:
             return records
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.kafka_source'
