@@ -5,13 +5,19 @@ from typing import (
     Iterator, List, Optional, Union,
 )
 
+from amundsen_common.utils.atlas import AtlasCommonParams, AtlasCommonTypes
 from amundsen_rds.models import RDSModel
 from amundsen_rds.models.badge import Badge as RDSBadge
 
+from databuilder.models.atlas_entity import AtlasEntity
+from databuilder.models.atlas_relationship import AtlasRelationship
+from databuilder.models.atlas_serializable import AtlasSerializable
 from databuilder.models.graph_node import GraphNode
 from databuilder.models.graph_relationship import GraphRelationship
 from databuilder.models.graph_serializable import GraphSerializable
 from databuilder.models.table_serializable import TableSerializable
+from databuilder.serializers.atlas_serializer import get_entity_attrs
+from databuilder.utils.atlas import AtlasRelationshipTypes, AtlasSerializedEntityOperation
 
 
 class Badge:
@@ -29,11 +35,10 @@ class Badge:
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Badge):
             return NotImplemented
-        return self.name == other.name and \
-            self.category == other.category
+        return self.name == other.name and self.category == other.category
 
 
-class BadgeMetadata(GraphSerializable, TableSerializable):
+class BadgeMetadata(GraphSerializable, TableSerializable, AtlasSerializable):
     """
     Badge model.
     """
@@ -45,7 +50,7 @@ class BadgeMetadata(GraphSerializable, TableSerializable):
     BADGE_RELATION_TYPE = 'HAS_BADGE'
     INVERSE_BADGE_RELATION_TYPE = 'BADGE_FOR'
 
-    LABELS_PERMITTED_TO_HAVE_BADGE = ['Table', 'Dashboard', 'Column', 'Feature']
+    LABELS_PERMITTED_TO_HAVE_BADGE = ['Table', 'Dashboard', 'Column', 'Feature', 'Type_Metadata']
 
     def __init__(self,
                  start_label: str,
@@ -61,6 +66,8 @@ class BadgeMetadata(GraphSerializable, TableSerializable):
         self._node_iter = self._create_node_iterator()
         self._relation_iter = self._create_relation_iterator()
         self._record_iter = self._create_record_iterator()
+        self._atlas_entity_iterator = self._create_next_atlas_entity()
+        self._atlas_relation_iterator = self._create_atlas_relation_iterator()
 
     def __repr__(self) -> str:
         return f'BadgeMetadata({self.start_label!r}, {self.start_key!r}, {self.badges!r})'
@@ -148,3 +155,53 @@ class BadgeMetadata(GraphSerializable, TableSerializable):
         records = self.get_badge_records()
         for record in records:
             yield record
+
+    def _create_atlas_classification_entity(self, badge: Badge) -> AtlasEntity:
+        attrs_mapping = [
+            (AtlasCommonParams.qualified_name, badge.name),
+            ('category', badge.category),
+            ('name', badge.name)
+        ]
+
+        entity_attrs = get_entity_attrs(attrs_mapping)
+
+        entity = AtlasEntity(
+            typeName=AtlasCommonTypes.badge,
+            operation=AtlasSerializedEntityOperation.CREATE,
+            attributes=entity_attrs,
+            relationships=None
+        )
+
+        return entity
+
+    def _create_atlas_classification_relation(self, badge: Badge) -> AtlasRelationship:
+        table_relationship = AtlasRelationship(
+            relationshipType=AtlasRelationshipTypes.badge,
+            entityType1=AtlasCommonTypes.data_set,
+            entityQualifiedName1=self.start_key,
+            entityType2=AtlasRelationshipTypes.badge,
+            entityQualifiedName2=badge.name,
+            attributes={}
+        )
+
+        return table_relationship
+
+    def _create_atlas_relation_iterator(self) -> Iterator[AtlasRelationship]:
+        for badge in self.badges:
+            yield self._create_atlas_classification_relation(badge)
+
+    def create_next_atlas_relation(self) -> Union[AtlasRelationship, None]:
+        try:
+            return next(self._atlas_relation_iterator)
+        except StopIteration:
+            return None
+
+    def _create_next_atlas_entity(self) -> Iterator[AtlasEntity]:
+        for badge in self.badges:
+            yield self._create_atlas_classification_entity(badge)
+
+    def create_next_atlas_entity(self) -> Union[AtlasEntity, None]:
+        try:
+            return next(self._atlas_entity_iterator)
+        except StopIteration:
+            return None
